# The following macros can be changed.

# Use this to specify the sysconfig location (usually either /etc or %{_prefix}/etc
%define _sysconfdir %{_prefix}/etc

# Remove the edg prefix from binaries and man pages
%define disable_edg_prefix 1

# Specify the type of RPM dependencies depending on which version og Globus is used
%define use_modular_globus 1

#
%define enable_userdocs 0

Name: voms
Version: 1.6.7
Release: 1
License: EU DataGrid Software License
URL: http://grid-auth.infn.it/

Source: %{name}-%{version}.tar.gz

# Patches
#
# o voms_gcc.patch
#   - ??
# o voms_flavored_libs.patch
#   - Enable flavored/non-flavored voms libraries
# o voms_noglobusopenssl.patch
#   - Use external openssl - not globus_openssl
# o voms_nostaticlibs.patch
#   - Make shared libs (no -static)
# o voms_nops.patch
#   - Dont make postscript versions of reference manual

Patch0: voms_gcc.patch
Patch1: voms_flavored_libs.patch
Patch2: voms_noglobusopenssl.patch
Patch3: voms_nostaticlibs.patch
#Patch4: voms_nops.patch
Patch5: voms_c_link.patch

BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root
BuildRequires: expat-devel
BuildRequires: mysql-devel

# For docs
BuildRequires: doxygen
BuildRequires: docbook-utils
BuildRequires: docbook-utils-pdf
BuildRequires: ghostscript

BuildRequires: libtool-ltdl-devel

%if %{use_modular_globus}
Requires: globus_core
Requires: globus_openssl-devel
Requires: globus_gssapi_gsi-devel
Requires: globus_gss_assist-devel
%else
BuildRequires: globus
%endif

Summary: Virtual Organization Membership Service
Group: Grid
Requires: expat
%if %{use_modular_globus}
Requires: globus_openssl
Requires: globus_gssapi_gsi
Requires: globus_gss_assist
%else
Requires: globus
%endif
Prefix: %{_prefix}
Prefix: %{_sysconfdir}
%description
VOMS - Virtual Organization Membership Service.

%package devel
Summary: Virtual Organization Membership Service
Group: Grid
Requires: voms
Prefix: %{_prefix}
%description devel
VOMS - Virtual Organization Membership Service.

%package clients
Summary: Virtual Organization Membership Service
Group: Grid
Requires: voms
%if %{use_modular_globus}
Requires: globus_openssl
Requires: globus_gssapi_gsi
Requires: globus_gss_assist
%else
Requires: globus
%endif
Prefix: %{_prefix}
%description clients
VOMS - Virtual Organization Membership Service.

%package server
Summary: Virtual Organization Membership Service
Group: Grid
Requires: voms
Requires: mysql
%if %{use_modular_globus}
Requires: globus_openssl
Requires: globus_gssapi_gsi
Requires: globus_gss_assist
%else
Requires: globus
%endif
Prefix: %{_prefix}
Prefix: %{_sysconfdir}
%description server
VOMS - Virtual Organization Membership Service.

%prep
%setup -q
%patch0 -p1
%patch1 -p1
%patch2 -p1
%patch3 -p1

%if %{?disable_edg_prefix:1}
for i in server utils client doc
do
  perl -p -i.orig  -e 's/edg-voms/voms/g; s/^edg_voms/voms/; s/install-exec-hook:.*\n//; s/^[\t ]*-ln .*\n//' $i/Makefile.am
done
cd doc
for i in edg-voms*
do
  mv $i `echo $i|sed 's/^edg-voms/voms/'`;
done
for i in *sgml
do
  perl -p -i.orig  -e 's/edg-voms/voms/g; s/^edg_voms/voms/;' $i
done
cd ..
%endif

# Force pdflatex
# %patch4 -p1
# for i in api/ccapi/Makefile.am api/ccapi/Makefile.in; do
#   cp -p $i $i.save
#   cat $i.save | sed 's!\(^USE_PDFLATEX.*\)NO\(.*\)!\1YES\2!' > $i
#   rm -f $i.save
# done

# C linkage
%patch5 -p1

%if %{!enable_userdocs}
for i in Makefile.am Makefile.in; do
  cp -p $i $i.save
  cat $i.save |grep -v ^all-local: > $i
  rm -f $i.save
done
%endif

%build

# Detect Globus installation
# - Check GLOBUS_LOCATION variable
# - Otherwise see if $GLOBUS_LOCATION/bin is in the path
#   and use globus-makefile-header from globus_common to determine GLOBUS_LOCATION 
if test "x$GLOBUS_LOCATION" = "x"
then
	for p in  `echo $PATH |tr : ' '`
  do
    if test -f $p/globus-makefile-header
    then
      GLOBUS_LOCATION=`dirname $p`
      break
    fi
  done
fi

if test -d "$GLOBUS_LOCATION"
then
	:
else
  echo "GLOBUS_LOCATION not set or is not a directory"
  exit 1
fi

#
# Try to detect/guess Globus flavor
#

if test -d "$GPT_LOCATION"
then
  globus_flavor=`$GPT_LOCATION/sbin/gpt-flavor-configuration |grep '^[a-zA-Z0-9]*:'|cut -f1 -d:|tail -1`
else
  globus_flavor=`gpt-flavor-configuration |grep '^[a-zA-Z0-9]*:'|cut -f1 -d:|tail -1`
fi
if test "$globus_flavor" = ""
then
  echo "Globus flavor could not be guessed"
  exit 1
fi

# The following line is need for a raw CVS checkout
rm -fr autom4te.cache config.*
./autobuild.sh
./configure --prefix=%{_prefix} --with-globus-location=$GLOBUS_LOCATION --with-globus-flavor=${globus_flavor} --libdir=%{_libdir} --enable-docs
make

%install
rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT%{_prefix}/share/doc/voms-api-%{version}
make install DESTDIR=$RPM_BUILD_ROOT

# Remove unessary and unwanted installed files
rm -f  $RPM_BUILD_ROOT%{_libexecdir}/voms/testvoms
rm -f  $RPM_BUILD_ROOT%{_mandir}/man1/testvoms.1.gz
rm -fr $RPM_BUILD_ROOT%{_prefix}/share/doc

%clean
rm -rf $RPM_BUILD_ROOT

%files
%defattr(-,root,root,-)
%doc AUTHORS DEPENDENCIES INSTALL LICENSE MAINTAINERS README
%if %{enable_userdocs}
%doc doc/software.pdf
%endif
%{_sysconfdir}/vomses.template
%{_libdir}/libvomsapi.so.0
%{_libdir}/libvomsapi.so.0.0.0
%{_libdir}/libvomsc.so.0
%{_libdir}/libvomsc.so.0.0.0

%files clients
%defattr(-,root,root,-)
%{_bindir}/voms-proxy-destroy
%{_bindir}/voms-proxy-info
%{_bindir}/voms-proxy-init
%{_bindir}/voms-proxy-fake
%{_mandir}/man1/voms-proxy-destroy.1.gz
%{_mandir}/man1/voms-proxy-info.1.gz
%{_mandir}/man1/voms-proxy-init.1.gz
%{_mandir}/man1/voms-proxy-fake.1.gz
%{_mandir}/man1/voms-proxy-list.1.gz
%if %{?disable_edg_prefix: 0}
%{_bindir}/edg-voms-proxy-destroy
%{_bindir}/edg-voms-proxy-info
%{_bindir}/edg-voms-proxy-init
%{_bindir}/edg-voms-proxy-fake
%{_mandir}/man1/edg-voms-proxy-destroy.1.gz
%{_mandir}/man1/edg-voms-proxy-info.1.gz
%{_mandir}/man1/edg-voms-proxy-init.1.gz
%{_mandir}/man1/voms-proxy-fake.1.gz
%endif

%files server
%defattr(-,root,root,-)
%{_sbindir}/voms
%{_sbindir}/voms_install_replica
%{_sysconfdir}/init.d/voms
%{_sysconfdir}/voms/voms.data
%{_libexecdir}/voms/upgrade1to2
%{_libexecdir}/voms/voms_install_db
%{_mandir}/man1/voms_install_db.1.gz
%{_mandir}/man1/voms_install_replica.1.gz
%{_mandir}/man8/voms.8.gz
%if %{?disable_edg_prefix: 0}
%{_sbindir}/edg-voms
%{_mandir}/man8/edg-voms.8.gz
%endif

%files devel
%defattr(-,root,root,-)
%if %{enable_userdocs}
%doc doc/capi.pdf doc/c++api.pdf doc/AC-RFC.pdf 
%endif
%doc doc/VOMS-v1_1.pdf
%{_includedir}/acstack.h
%{_includedir}/newformat.h
%{_includedir}/voms_api.h
%{_includedir}/voms_apic.h
%{_libdir}/libvomsapi.a
%{_libdir}/libvomsapi.la
%{_libdir}/libvomsapi.so
%{_libdir}/libvomsc.a
%{_libdir}/libvomsc.la
%{_libdir}/libvomsc.so
%{_mandir}/man3/data.3.gz
%{_mandir}/man3/voms.3.gz
%{_mandir}/man3/voms_api.h.3.gz
%{_mandir}/man3/voms_apic.h.3.gz
%{_mandir}/man3/vomsdata.3.gz

%changelog
* Tue Oct 18 2005 Anders Waananen <waananen@nbi.dk> - 1.6.7-1
- Modfiy voms_noglobusopenssl.patch to match upstream
- Add patch voms_nops.patch to disable postscript versions of reference manual
* Fri Jun 17 2005 Anders Waananen <waananen@nbi.dk> - 1.5.4-1
- Remove the following patches:
  - voms_namespace.patch - Fixed in upstream
  - voms_external_mysql++-1.4.1.patch - Obsolete since mysql++ is no longer needed
  - voms-no_libs.path - Fixed in upstream
- Add Globus dependencies
* Wed Jun  1 2005 Anders Waananen <waananen@nbi.dk> - 1.4.1-3
- Do not hardcode Globus flavor but try to guess
- Remove explicit globus rpm Requirement
- Use external openssl - not globus_openssl
* Mon May  2 2005 Anders Waananen <waananen@nbi.dk> - 1.4.1-2
- Remove automake cache
- Add explicit dependency on mysql++-devel
* Sat Apr 30 2005 Anders Waananen <waananen@nbi.dk> - 1.4.1-1
- New upstream
- autogen.sh -> autobuild.sh
* Mon Apr 18 2005 Anders Waananen <waananen@nbi.dk> - 1.3.2-1
- Initial build.
